==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-sensors/translations/sensors_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>הגדרות חיישנים</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>משותף</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>מרווח בין עדכונים (שניות)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>רוחב סרגל מעלות</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>סולם מעלות</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>צלזיוס</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>פרנהייט</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>אזהרה על מעלות גבוהות</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>חיישנים</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>שבבים שהתגלו:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>תכונות שבב:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>מופעל</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>תווית</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>צבע</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-sensors/translations/sensors_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>הגדרות חיישנים</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>משותף</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>מרווח בין עדכונים (שניות)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>רוחב סרגל מעלות</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>סולם מעלות</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>צלזיוס</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>פרנהייט</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation>להבהב את שורות המצב כשהטמפרטורה גבוהה מדי</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>אזהרה על מעלות גבוהות</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>חיישנים</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>שבבים שהתגלו:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>תכונות שבב:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>מופעל</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>תווית</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>צבע</translation>
    </message>
</context>
</TS>
